--- ../commoncpp/src/socket.h	Fri Nov 16 12:22:50 2001
+++ src/socket.h	Wed Nov 28 17:04:49 2001
@@ -1058,6 +1058,16 @@
  */
 class UDPTransmit : private UDPSocket
 {
+private:
+	/** 
+	 * Common code for diferent flavours of Connect (host, broadcast,
+	 * multicast).
+	 *
+	 * @param ia network address to associate with
+	 * @param port port number to associate with
+	 */
+	sockerror_t CConnect(const InetAddress &ia, tpport_t port);
+
 protected:
 	/**
 	 * Create a UDP transmitter.
@@ -1099,6 +1109,15 @@
 	sockerror_t Connect(const BroadcastAddress &subnet, tpport_t port);
 
 	/**
+	 * Associate this socket with a multicast group.  
+	 *
+	 * @return 0 on success, -1 on error.
+	 * @param mgroup address of the multicast group to send to. 
+	 * @param port port number
+	 */
+	sockerror_t Connect(const InetMcastAddress &group, tpport_t port);
+
+	/**
 	 * Disassociate this socket from any host connection.  No data
 	 * should be read or written until a connection is established.
 	 */
@@ -1128,6 +1147,12 @@
 	inline SOCKET getTransmitter(void)
 		{return so;};
 
+	inline sockerror_t setMulticast(bool enable)
+		{return Socket::setMulticast(enable);};
+
+	inline sockerror_t setTimeToLive(unsigned char ttl)
+		{return Socket::setTimeToLive(ttl);};
+
 public:
 	/**
 	 * Transmit "send" to use "connected" send rather than sendto.
@@ -1221,6 +1246,15 @@
 
 	inline sockerror_t setRouting(bool enable)
 		{return Socket::setRouting(enable);};
+
+	inline sockerror_t setMulticast(bool enable)
+		{return Socket::setMulticast(enable);};
+
+	inline sockerror_t Join(const InetMcastAddress &ia)
+	        {return Socket::Join(ia);}
+
+	inline sockerror_t Drop(const InetMcastAddress &ia)
+	        {return Socket::Drop(ia);}
 
 public:
 	/**
